@@ -8,6 +8,7 @@ from .ParameterStructure.Instances import InstanceType
 # from copy import deepcopy
 # from functools import lru_cache
 from tqdm import tqdm
+from copy import copy
 
 logger = colorlog.getLogger('PySimultan')
 
@@ -442,7 +443,6 @@ def create_geo_classes(geo_types):
         def points(self):
             return self.boundary.points
 
-
     class GeometricVolume(geo_types['volume']):
 
         def __init__(self, *args, **kwargs):
@@ -452,7 +452,10 @@ def create_geo_classes(geo_types):
         @property
         def faces(self):
             if self._faces is None:
-                self._faces = [GeometricFace.get_obj_by_id(x.Face.Id) for x in self._wrapped_obj.Faces.Items]
+                _faces = [GeometricFace.get_obj_by_id(x.Face.Id) for x in self._wrapped_obj.Faces.Items]
+                all_faces = copy(_faces)
+                [all_faces.extend(x.hole_faces) for x in _faces]
+                self._faces = all_faces
             return self._faces
 
         @faces.setter
